"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var escape_string_regexp_1 = __importDefault(require("escape-string-regexp"));
function compilePattern(pattern) {
    var regexpParts = [];
    var matchParts = [];
    pattern.split(/\{\{(\w+(?::\w+)?)\}\}/).forEach(function (part, i) {
        if (i % 2 === 0) {
            regexpParts.push(part
                .split(/\s+/)
                .map(function (x) { return escape_string_regexp_1.default(x); })
                .join("\\s*"));
        }
        else {
            var subparts = part.split(':');
            var key = subparts[0];
            var matcherName = subparts[1] || 'string';
            var matcher = placeholderMatchers[matcherName];
            regexpParts.push("(" + matcher.regexp + ")");
            matchParts.push({ key: key, matcher: matcher });
        }
    });
    var regexp = new RegExp("^\\s*" + regexpParts.join('') + "\\s*$", 'i');
    return {
        execute: function (text) {
            var match = regexp.exec(text);
            if (!match)
                return null;
            var output = {};
            matchParts.forEach(function (part, i) {
                output[part.key] = part.matcher.process(match[i + 1]);
            });
            return output;
        }
    };
}
exports.compilePattern = compilePattern;
var placeholderMatchers = {
    string: {
        regexp: ".+?",
        process: function (matchedText) { return matchedText; }
    },
    number: {
        regexp: "[0-9,.-]+",
        process: function (matchedText) { return parseFloat(matchedText.replace(/,/g, '')).toFixed(2); }
    },
    kbank_date: {
        regexp: "\\d\\d\\/\\d\\d\\/\\d\\d",
        process: function (matchedText) {
            var _a = matchedText.split('/'), a = _a[0], b = _a[1], c = _a[2];
            return "20" + c + "-" + b + "-" + a;
        }
    },
    time: {
        regexp: "\\d\\d?:\\d\\d",
        process: function (matchedText) { return (matchedText.length < 5 ? '0' : '') + matchedText; }
    }
};
//# sourceMappingURL=PatternMatcher.js.map